
# Type: genotype to genotype part association_object




URI: [biolink:genotype_to_genotype_part_association_object](https://w3id.org/biolink/vocab/genotype_to_genotype_part_association_object)


## Domain and Range

[GenotypeToGenotypePartAssociation](GenotypeToGenotypePartAssociation.md) ->  <sub>REQ</sub> [Genotype](Genotype.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [GenotypeToGenotypePartAssociation](GenotypeToGenotypePartAssociation.md)
